@@ -25,6 +25,10 @@
 #include <freeradius/ident.h>
 RCSIDH(rad_assert_h, "$Id$")
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 extern void rad_assert_fail (const char *file, unsigned int line, const char *expr);
 
 #ifdef NDEBUG
@@ -40,4 +44,8 @@ extern void rad_assert_fail (const char *file, unsigned int line, const char *ex
 #define rad_assert assert
 #endif
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
